@@ -156,14 +156,18 @@ FSelectInstanceBatchSingleCrit = R6Class("FSelectInstanceBatchSingleCrit",
     #'
     #' @param ... (ignored).
     print = function(...) {
-      catf(format(self))
-      catf(str_indent("* State: ", if (is.null(private$.result)) "Not optimized" else "Optimized"))
-      catf(str_indent("* Objective:", format(self$objective)))
-      catf(str_indent("* Terminator:", format(self$terminator)))
+      is_optimized = if (is.null(private$.result)) "Not optimized" else "Optimized"
+      cat_cli({
+        cli_h1("{.cls {class(self)[1L]}}")
+        cli_li("State: {is_optimized}")
+        cli_li("Objective: {.cls {class(self$objective)[1]}} ({self$objective$id})")
+        cli_li("Terminator: {.cls {class(self$terminator)[1]}}")
+      })
+
       if (!is.null(private$.result)) {
-        catf("* Result:")
+        cat_cli(cli_li("Result:"))
         print(self$result[, c(self$archive$cols_x, self$archive$cols_y), with = FALSE])
-        catf("* Archive:")
+        cat_cli(cli_li("Archive:"))
         print(as.data.table(self$archive)[, c(self$archive$cols_x, self$archive$cols_y), with = FALSE])
       }
     }
